@@ -11,9 +11,9 @@ path '/' => sub {
     };
 };
 
-path '/subapp' => 'Nephia::SubApp';
-path '/childapp' => '+ChildApp';
-path '/subapp2' => 'Nephia::SubApp';
+path '/subapp' => '+Nephia::SubApp';
+path '/childapp' => 'ChildApp';
+path '/subapp2' => '+Nephia::SubApp';
 
 1;
 
